@@ -23,7 +23,7 @@ import urllib
 from zope.authentication.interfaces import IAuthentication
 from zope.interface import Interface
 from zope.publisher.interfaces import NotFound
-from zope.schema import Password, TextLine, Bytes, Bool
+from zope.schema import Password
 from zope.schema.interfaces import ValidationError
 from zope.schema.interfaces import IIterableSource
 from zope.schema.interfaces import ITitledTokenizedTerm
@@ -31,12 +31,8 @@ from zope.proxy import sameProxiedObjects
 from zope.security import checkPermission
 from zope.security.proxy import removeSecurityProxy
 from zope.security.checker import canAccess
-from zope.app.form.browser.add import AddView
 from zope.app.form.browser.source import SourceMultiCheckBoxWidget as SourceMultiCheckBoxWidget_
 from zope.app.form.browser.interfaces import ITerms
-from zope.app.form.interfaces import IInputWidget
-from zope.app.form.interfaces import WidgetsError
-from zope.app.form.utility import getWidgetsData, setUpWidgets
 from zope.app.dependable.interfaces import IDependable
 from zope.publisher.browser import BrowserView
 from zope.viewlet.interfaces import IViewletManager
@@ -66,9 +62,10 @@ from schooltool.person.interfaces import IPersonPreferences
 from schooltool.person.interfaces import IPersonContainer, IPersonContained
 from schooltool import table
 from schooltool.skin import flourish
-from schooltool.skin.containers import TableContainerView
 from schooltool.securitypolicy.crowds import Crowd
 from schooltool.securitypolicy.interfaces import ICrowd
+from schooltool.table.column import IndexedLocaleAwareGetterColumn
+from schooltool.table.table import url_cell_formatter
 
 
 def SourceMultiCheckBoxWidget(field, request):
@@ -103,8 +100,7 @@ class CalendarPublicWidgetTerms(term.BoolTerms):
     def falseLabel(self):
         person = self.context.__parent__
         return _('${person_full_name} and school administration',
-                 mapping={'person_full_name': "%s %s" % (person.first_name,
-                                                         person.last_name)})
+                 mapping={'person_full_name': person.title})
 
 
 class CalendarPeriodsRadioWidget(RadioWidget):
@@ -126,8 +122,7 @@ class CalendarPublicRadioWidget(RadioWidget):
 def calendar_public_widget_label(adapter):
     person = adapter.context.__parent__
     return _("${person_full_name}'s calendar is visible to...",
-             mapping={'person_full_name': "%s %s" % (person.first_name,
-                                                     person.last_name)})
+             mapping={'person_full_name': person.title})
 
 
 CalendarPublicWidgetLabel = widget.ComputedWidgetAttribute(
@@ -156,8 +151,7 @@ class PersonPreferencesView(form.EditForm):
     def label(self):
         person = self.context.__parent__
         return _(u'Change preferences for ${person_full_name}',
-                 mapping={'person_full_name': "%s %s" % (person.first_name,
-                                                         person.last_name)})
+                 mapping={'person_full_name': person.title})
 
     @button.buttonAndHandler(_("Apply"))
     def handle_edit_action(self, action):
@@ -239,8 +233,7 @@ class FlourishPersonPreferencesLink(flourish.page.ModalFormLinkViewlet):
     def dialog_title(self):
         person = self.context
         title = _(u'Change preferences for ${person_full_name}',
-                  mapping={'person_full_name': "%s %s" % (person.first_name,
-                                                          person.last_name)})
+                  mapping={'person_full_name': person.title})
         return translate(title, context=self.request)
 
 
@@ -276,8 +269,7 @@ class FlourishPersonDeleteLink(flourish.page.ModalFormLinkViewlet):
     def dialog_title(self):
         person = self.context
         title = _(u'Delete ${person_full_name}',
-                  mapping={'person_full_name': "%s %s" % (person.first_name,
-                                                          person.last_name)})
+                  mapping={'person_full_name': person.title})
         return translate(title, context=self.request)
 
     def render(self, *args, **kw):
@@ -563,6 +555,27 @@ class PersonTableFilter(table.ajax.IndexedTableFilter,
         return PersonFilterWidget.filter(self, results)
 
 
+def person_table_columns():
+    """Columns for the old person table.
+
+    Functional tests expect the first column to be first name."""
+    first_name = IndexedLocaleAwareGetterColumn(
+        index='first_name',
+        name='first_name',
+        cell_formatter=url_cell_formatter,
+        title=_(u'First Name'),
+        getter=lambda i, f: i.first_name,
+        subsort=True)
+    last_name = IndexedLocaleAwareGetterColumn(
+        index='last_name',
+        name='last_name',
+        cell_formatter=url_cell_formatter,
+        title=_(u'Last Name'),
+        getter=lambda i, f: i.last_name,
+        subsort=True)
+    return [first_name, last_name]
+
+
 class PersonTable(table.ajax.IndexedTable):
 
     @property
@@ -570,7 +583,7 @@ class PersonTable(table.ajax.IndexedTable):
         return ISchoolToolApplication(None)['persons']
 
     def columns(self):
-        return getUtility(IPersonFactory).columns()
+        return person_table_columns()
 
     def sortOn(self):
         return getUtility(IPersonFactory).sortOn()
@@ -580,187 +593,12 @@ class PersonTableFormatter(table.catalog.IndexedTableFormatter):
     """Person container specific table formatter."""
 
     def columns(self):
-        return getUtility(IPersonFactory).columns()
+        return person_table_columns()
 
     def sortOn(self):
         return getUtility(IPersonFactory).sortOn()
 
 
-class IPersonAddForm(Interface):
-    """Schema for person adding form."""
-
-    title = TextLine(
-        title=_("Full name"),
-        description=_("Name that should be displayed"))
-
-    username = TextLine(
-        title=_("Username"),
-        description=_("Username"))
-
-    password = Password(
-        title=_("Password"),
-        required=False)
-
-    verify_password = Password(
-        title=_("Verify password"),
-        required=False)
-
-    photo = Bytes(
-        title=_("Photo"),
-        required=False,
-        description=_("""Photo (in JPEG format)"""))
-
-
-class PersonAddView(AddView):
-    """A view for adding a person."""
-
-    __used_for__ = IPersonContainer
-
-    # Form error message for the page template
-    error = None
-
-    # Override some fields of AddView
-    schema = IPersonAddForm
-    _arguments = ['title', 'username', 'password', 'photo']
-    _keyword_arguments = []
-    _set_before_add = [] # getFieldNamesInOrder(schema)
-    _set_after_add = []
-
-    def createAndAdd(self, data):
-        """Create a Person from form data and add it to the container."""
-        if data['password'] != data['verify_password']:
-            self.error = _("Passwords do not match")
-            raise WidgetsError([ValidationError(self.error)])
-        elif data['username'] in self.context:
-            self.error = _('This username is already in use')
-            raise WidgetsError([ValidationError(self.error)])
-        return AddView.createAndAdd(self, data)
-
-    def getAllGroups(self):
-        """Return a list of all groups in the system."""
-        gc = IGroupContainer(ISchoolToolApplication(None), {})
-        return gc.values()
-
-    def create(self, title, username, password, photo):
-        person = self._factory(username=username, title=title)
-        person.setPassword(password)
-        person.photo = photo
-        return person
-
-    def _factory(self, username, title):
-        return getUtility(IPersonFactory)(username, title)
-
-    def add(self, person):
-        """Add `person` to the container.
-
-        Uses the username of `person` as the object ID (__name__).
-        """
-        person_groups = removeSecurityProxy(person.groups)
-        for group in self.getAllGroups():
-            if 'group.' + group.__name__ in self.request:
-                person.groups.add(removeSecurityProxy(group))
-        name = person.username
-        self.context[name] = person
-        return person
-
-    def update(self):
-        if 'CANCEL' in self.request:
-            url = absoluteURL(self.context, self.request)
-            self.request.response.redirect(url)
-
-        return AddView.update(self)
-
-    def nextURL(self):
-        """See zope.browser.interfaces.IAdding"""
-        return absoluteURL(self.context, self.request)
-
-
-class IPersonEditForm(Interface):
-    """Schema for a person's edit form."""
-
-    title = TextLine(
-        title=_("Full name"),
-        description=_("Name that should be displayed"))
-
-    photo = Bytes(
-        title=_("New photo"),
-        required=False,
-        description=_(
-            """A small picture (about 48x48 pixels in JPEG format)"""))
-
-    clear_photo = Bool(
-        title=_("Clear photo"),
-        required=False,
-        description=_("""Check this to clear the photo"""))
-
-    new_password = Password(
-        title=_("New password"),
-        required=False)
-
-    verify_password = Password(
-        title=_("Verify password"),
-        required=False)
-
-
-class PersonEditView(BrowserView):
-    """A view for editing a person."""
-
-    __used_for__ = IPersonContained
-
-    error = None
-    message = None
-
-    def __init__(self, context, request):
-        BrowserView.__init__(self, context, request)
-        setUpWidgets(self, IPersonEditForm, IInputWidget,
-                     initial={'title': self.context.title,
-                              'photo': self.context.photo})
-
-    def update(self):
-        if 'UPDATE_SUBMIT' in self.request:
-            try:
-                data = getWidgetsData(self, IPersonEditForm)
-            except WidgetsError:
-                return # Errors will be displayed next to widgets
-
-            # If any of the password fields is set
-            if data.get('new_password') or data.get('verify_password'):
-                # We compare them
-                if data['new_password'] != data['verify_password']:
-                    self.error = _("Passwords do not match")
-                    return
-
-                self.context.setPassword(data['new_password'])
-                self.message = _("Password changed successfully")
-
-            self.context.title = data['title']
-            if data.get('photo'):
-                self.context.photo = data['photo']
-
-            if data.get('clear_photo'):
-                self.context.photo = None
-                # Uncheck the checkbox before rendering the form
-                self.clear_photo_widget.setRenderedValue(False)
-
-        if 'CANCEL' in self.request:
-            url = absoluteURL(self.context, self.request)
-            self.request.response.redirect(url)
-
-
-class PersonContainerView(TableContainerView):
-    """A Person Container view."""
-
-    __used_for__ = IPersonContainer
-
-    delete_template = ViewPageTemplateFile("person_container_delete.pt")
-
-    index_title = _("Person index")
-
-    def isDeletingHimself(self):
-        person = IPerson(self.request.principal, None)
-        return person in self.itemsToDelete
-
-
 class PersonView(BrowserView):
     """A Person info view."""
 
@@ -769,6 +607,7 @@ class PersonView(BrowserView):
     def __init__(self, context, request):
         BrowserView.__init__(self, context, request)
 
+
 class HomeView(PersonView):
     """A Person's homepage."""
 
